@@ -1,4 +1,4 @@
-
+#UTF-8
 
 from time import sleep
 import os
@@ -74,10 +74,11 @@ class Remote_operation():
 class LinuxLocalOperation():
     def start_mock_server(self,mock_server_port):
         self.stop_mock_server(mock_server_port)
+        subprocess.Popen("python3 mock_server_code.py", stdout=None, shell=True)
 
     def stop_mock_server(self,mock_server_port):
         stop_port_process_cmd = "netstat -ntlp | grep ':"+str(mock_server_port)+" '  |  awk '{print $7}' |  awk -F '/' '{print $1}' | xargs kill -9"
-        self.remote_operation.exec_remote_shell(stop_port_process_cmd)
+        subprocess.Popen(stop_port_process_cmd,  stdout=None, shell=True)
 
 
 class LinuxRemoteOperation():
